slepc-3.18.0 2022-10-01
Report Typos and Errors

# PEPExtract

The extraction type

### Synopsis

    typedef enum { PEP_EXTRACT_NONE=1,
                   PEP_EXTRACT_NORM,
                   PEP_EXTRACT_RESIDUAL,
                   PEP_EXTRACT_STRUCTURED } PEPExtract;

### See Also

PEPSetExtract()

### Level

intermediate

### Location

include/slepcpep.h
Index of all PEP routines
Table of Contents for all manual pages
Index of all manual pages